==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clear log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 week</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 month</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>3 months</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Emergency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alert</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Debug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Event Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PID:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Action:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Login record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Debug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Emergency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alert</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Process</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Date and Time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Event Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Process:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Info:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PID:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.10+ds1.orig.tar.xz: deepin-log-viewer-6.5.10/translations/deepin-log-viewer_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Bersihkan log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Segarkan</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Anda yakin akan membersihkan log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hari ini</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 hari</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 minggu</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 bulan</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 bulan</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Ekspor</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Darurat</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritis</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Galat</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Pemberitahuan</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Awakutu</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Log masuk</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Sangat kritis</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Autentikasi identitas</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Kontrol Akses Diskresi</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Kontrol akses wajib</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Remote</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Audit dokumen</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Lainnya</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Mengekspor...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Ekspor berhasil</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ekspor gagal</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Direktori ekspor tidak tersedia. Pilih direktori lainnya untuk menjalankan ekspor.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Ekspor berkas</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periode:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Tingkat:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipe Acara:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Pengguna:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Aksi:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rekaman boot</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Rekaman shutdown</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>rekaman log masuk</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Tipe audit:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Aplikasi:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Submodul:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Awakutu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Galat</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Darurat</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritis</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Pemberitahuan</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Sangat kritis</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Log berkas kosong</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Pembaca log</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Pembaca log adalah alat yang berguna untuk melihat log sistem.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Hasil tidak ditemukan</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Tingkat</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tanggal dan Waktu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Sumber</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aksi</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Jenis acara</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Tingkat:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proses:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tanggal dan Waktu:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Pengguna:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nama Berkas</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Waktu diubah</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Berkas inti</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Nama Pengguna</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Offset</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tanggal dan Waktu</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Log Sistem</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Log Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Log Boot</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Log dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Log Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Log Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Log Aplikasi</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
